==> zio-aws-route53recoverycontrolconfig_3-5.17.121.3-sources.jar: zio/aws/route53recoverycontrolconfig/model/UpdateRoutingControlRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.{
  __stringMin1Max64PatternS,
  __stringMin1Max256PatternAZaZ09
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class UpdateRoutingControlRequest(
    routingControlArn: __stringMin1Max256PatternAZaZ09,
    routingControlName: __stringMin1Max64PatternS
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateRoutingControlRequest = {
    import UpdateRoutingControlRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateRoutingControlRequest
      .builder()
      .routingControlArn(
        __stringMin1Max256PatternAZaZ09.unwrap(
          routingControlArn
        ): java.lang.String
      )
      .routingControlName(
        __stringMin1Max64PatternS.unwrap(routingControlName): java.lang.String
      )
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.UpdateRoutingControlRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.UpdateRoutingControlRequest
      .wrap(buildAwsValue())
}
object UpdateRoutingControlRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateRoutingControlRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.UpdateRoutingControlRequest =
      zio.aws.route53recoverycontrolconfig.model
        .UpdateRoutingControlRequest(routingControlArn, routingControlName)
    def routingControlArn: __stringMin1Max256PatternAZaZ09
    def routingControlName: __stringMin1Max64PatternS
    def getRoutingControlArn
        : ZIO[Any, Nothing, __stringMin1Max256PatternAZaZ09] =
      ZIO.succeed(routingControlArn)
    def getRoutingControlName: ZIO[Any, Nothing, __stringMin1Max64PatternS] =
      ZIO.succeed(routingControlName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateRoutingControlRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.UpdateRoutingControlRequest.ReadOnly {
    override val routingControlArn: __stringMin1Max256PatternAZaZ09 =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__stringMin1Max256PatternAZaZ09(impl.routingControlArn())
    override val routingControlName: __stringMin1Max64PatternS =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__stringMin1Max64PatternS(impl.routingControlName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateRoutingControlRequest
  ): zio.aws.route53recoverycontrolconfig.model.UpdateRoutingControlRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53recoverycontrolconfig_3-5.17.203.2-sources.jar: zio/aws/route53recoverycontrolconfig/model/UpdateRoutingControlRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.{
  __stringMin1Max64PatternS,
  __stringMin1Max256PatternAZaZ09
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class UpdateRoutingControlRequest(
    routingControlArn: __stringMin1Max256PatternAZaZ09,
    routingControlName: __stringMin1Max64PatternS
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateRoutingControlRequest = {
    import UpdateRoutingControlRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateRoutingControlRequest
      .builder()
      .routingControlArn(routingControlArn: java.lang.String)
      .routingControlName(routingControlName: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.UpdateRoutingControlRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.UpdateRoutingControlRequest
      .wrap(buildAwsValue())
}
object UpdateRoutingControlRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateRoutingControlRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.UpdateRoutingControlRequest =
      zio.aws.route53recoverycontrolconfig.model
        .UpdateRoutingControlRequest(routingControlArn, routingControlName)
    def routingControlArn: __stringMin1Max256PatternAZaZ09
    def routingControlName: __stringMin1Max64PatternS
    def getRoutingControlArn
        : ZIO[Any, Nothing, __stringMin1Max256PatternAZaZ09] =
      ZIO.succeed(routingControlArn)
    def getRoutingControlName: ZIO[Any, Nothing, __stringMin1Max64PatternS] =
      ZIO.succeed(routingControlName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateRoutingControlRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.UpdateRoutingControlRequest.ReadOnly {
    override val routingControlArn: __stringMin1Max256PatternAZaZ09 =
      impl.routingControlArn(): __stringMin1Max256PatternAZaZ09
    override val routingControlName: __stringMin1Max64PatternS =
      impl.routingControlName(): __stringMin1Max64PatternS
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.UpdateRoutingControlRequest
  ): zio.aws.route53recoverycontrolconfig.model.UpdateRoutingControlRequest.ReadOnly =
    new Wrapper(impl)
}
